import urlUtil from "@/util/urlUtil"
import {Directive, DirectiveBinding} from "vue"
import {Router} from "vue-router"

/**
 *  html 내부의 anchor를 탐색해서 router-link처럼 이동하게 한다.
 */
export default {
  mounted: (el: HTMLElement, binding: DirectiveBinding): void => {

    Array
        .from(el.getElementsByTagName("a"))
        .forEach((anchor) => {
          anchor.onclick = async (event: MouseEvent) => {
            const router = binding.instance?.$.appContext.config.globalProperties.$router as Router

            const href = anchor.getAttribute('href') || ''
            const isInternalLink = !!router && urlUtil.checkInternalLink(href)

            const target = anchor.getAttribute('target')?.toLowerCase()
            const isTargetSelf = !target || target === "_self"

            const routerBase = location.origin + (router?.options.history.base || '')
            const resultHref = (isInternalLink === "SAME_ORIGIN") && isTargetSelf
                ? urlUtil.extractUrlDifferentPart(href, routerBase)
                : href

            const useRouterLink = !event.altKey
                && !event.ctrlKey
                && !event.shiftKey
                && isInternalLink
                && target !== '_blank'

            if (useRouterLink) {
              event.preventDefault()
              await router.push(resultHref)
            }
          }
        })
  }
} as Directive